.. package documentation master file.

|project|
=========

.. include:: ../../README.md
    :header: Overview
    :parser: myst


.. devstatusalert:: beta
    :title: Development Status (%(literal)s)
    :body: This package is in early access and could be unstable.


.. toctree::
    :caption: Getting Started
    :maxdepth: 1

    installation
    usage


.. toctree::
    :caption: Scripts
    :glob:
    :titlesonly:

    scripts/*


.. autosummary::
    :caption: API
    :toctree: _autosummary
    :recursive:
    :fromconfig: project


.. projecturls::
    :caption: Project Urls
    :hidden:


.. toctree::
    :caption: References
    :hidden:
    :maxdepth: 1

    changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
